/*******************************************************************************
 * Copyright (c) 2003, 2004 Texas Instruments Incorporated and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     Texas Instruments - Initial API and implementation
 *******************************************************************************/

package org.eclipse.cdt.debug.mi.core.cdi.model;

import org.eclipse.cdt.debug.core.cdi.model.ICDIRegisterGroupObject;
import org.eclipse.cdt.debug.core.cdi.model.ICDIRegisterObject;

/**
 * Simple implementation of the ICDIRegisterGroupObject interface. 
 * 
 * Keeps the information about a register group. Its name and all  
 * the register objects that belong to that group. 
 */
public class RegisterGroupObject implements ICDIRegisterGroupObject {

	/**
	 * Construction. 
	 * @param name - the name of the register group. 
	 * @param registers - all registers belonging to this register group. 
	 */
	public RegisterGroupObject( String name, ICDIRegisterObject[] registers)
	{
		this.name = name;
		this.registers = registers;
	}

	/**
	 * Access method for the register objects. 
	 */
	public ICDIRegisterObject[] getRegisterObjects() {
		return registers;
	}

	/**
	 * Access method for the register group name. 
	 */
	public String getName() {
		return name;
	}

	/**
	 * The name of the regsiter group. 
	 */
	private String name;
	
	/**
	 * The list of the register object belonging to this group.   
	 */
	private ICDIRegisterObject[] registers;
}
